import 'dart:async';
import 'package:flutter/material.dart';
import 'package:url_launcher/url_launcher.dart';

class CallUrlLauncher {

  final bool launchInBrowser;
  final String urlToLaunch;

  CallUrlLauncher(this.urlToLaunch, this.launchInBrowser) {
    
    if (launchInBrowser) {
        _launched = _launchInBrowser(urlToLaunch);
    } else {
        _launched = _launchInWebViewOrVC(urlToLaunch);
    }

   new FutureBuilder<Null>(future: _launched, builder: _launchStatus);
  }

  Future<Null> _launched;

  Future<Null> _launchInBrowser(String url) async {
    if (await canLaunch(url)) {
      await launch(url, forceSafariVC: false, forceWebView: false);
    } else {
      throw 'Could not launch $url';
    }
  }

  Future<Null> _launchInWebViewOrVC(String url) async {
    if (await canLaunch(url)) {
      await launch(url, forceSafariVC: true, forceWebView: true);
    } else {
      throw 'Could not launch $url';
    }
  }

  Widget _launchStatus(BuildContext context, AsyncSnapshot<Null> snapshot) {
    if (snapshot.hasError) {
      return new Text('Error: ${snapshot.error}');
    } else {
      return const Text('');
    }
  }

}
